@@ -30,7 +30,7 @@ namespace KCDDB
       virtual ~SyncHTTPSubmit();
 
     protected:
-      virtual Result runJob(KIO::Job* job);
+      Result runJob(KIO::Job* job) Q_DECL_OVERRIDE;
   } ;
 }
 
